==> react-universal-canvas-0.2.4.tgz: package/src/context.js <==
import { NativeModules } from 'react-native'
import color from './color'

const { UniversalCanvasContext } = NativeModules

class Context {
  constructor(contextId) {
    this.contextId = contextId
    this.props = {
      lineWidth: 1
    }
  }
  setContext(contextId) {
    this.contextId = contextId
  }
  update() {
    UniversalCanvasContext.update(this.contextId)
  }

  // Colors,Styles,and Shadows
  set fillStyle(fillStyle) {
    UniversalCanvasContext.setFillStyle(this.contextId, color(fillStyle))
  }
  set strokeStyle(strokeStyle) {
    UniversalCanvasContext.setStrokeStyle(this.contextId, color(strokeStyle))
  }
  set shadowColor(shadowColor) {
    UniversalCanvasContext.setShadowColor(this.contextId, color(shadowColor))
  }
  set shadowBlur(shadowBlur) {
    UniversalCanvasContext.setShadowBlur(this.contextId, shadowBlur)
  }
  set shadowOffsetX(shadowOffsetX) {
    UniversalCanvasContext.setShadowOffsetX(this.contextId, shadowOffsetX)
  }
  set shadowOffsetY(shadowOffsetY) {
    UniversalCanvasContext.setShadowOffsetY(this.contextId, shadowOffsetY)
  }
  createLinearGradient() {
    UniversalCanvasContext.createLinearGradient(this.contextId)
  }
  createPattern() {
    UniversalCanvasContext.createPattern(this.contextId)
  }
  createRadialGradient() {
    UniversalCanvasContext.createRadialGradient(this.contextId)
  }
  addColorStop() {
    UniversalCanvasContext.addColorStop(this.contextId)
  }

  // Line Styles
  set lineCap(lineCap) {
    UniversalCanvasContext.setLineCap(this.contextId, lineCap)
  }
  set lineJoin(lineJoin) {
    UniversalCanvasContext.setLineJoin(this.contextId, lineJoin)
  }
  set lineWidth(lineWidth) {
    UniversalCanvasContext.setLineWidth(this.contextId, lineWidth)
  }
  set miterLimit(miterLimit) {
    UniversalCanvasContext.setMiterLimit(this.contextId, miterLimit)
  }
  //getLineDash() {
  //  UniversalCanvasContext.setMiterLimit(this.contextId,miterLimit)
  //}
  setLineDash(lineDash) {
    UniversalCanvasContext.setLineDash(this.contextId, lineDash)
  }
  set lineDashOffset(lineDashOffset) {
    UniversalCanvasContext.setLineDashOffset(this.contextId, lineDashOffset)
  }

  // Rectangle
  rect(x, y, width, height) {
    UniversalCanvasContext.rect(this.contextId, x, y, width, height)
  }
  fillRect(x, y, width, height) {
    UniversalCanvasContext.fillRect(this.contextId, x, y, width, height)
  }
  strokeRect(x, y, width, height) {
    UniversalCanvasContext.strokeRect(this.contextId, x, y, width, height)
  }
  clearRect(x, y, width, height) {
    UniversalCanvasContext.clearRect(this.contextId, x, y, width, height)
  }

  // Paths
  fill() {
    UniversalCanvasContext.fill(this.contextId)
  }
  stroke() {
    UniversalCanvasContext.stroke(this.contextId)
  }
  beginPath() {
    UniversalCanvasContext.beginPath(this.contextId)
  }
  moveTo(x, y) {
    UniversalCanvasContext.moveTo(this.contextId, x, y)
  }
  closePath() {
    UniversalCanvasContext.closePath(this.contextId)
  }
  lineTo(x, y) {
    UniversalCanvasContext.lineTo(this.contextId, x, y)
  }
  clip() {
    UniversalCanvasContext.clip(this.contextId)
  }
  quadraticCurveTo(x, y, cx, cy) {
    UniversalCanvasContext.quadraticCurveTo(this.contextId, x, y, cx, cy)
  }
  bezierCurveTo(x, y, c1x, c1y, c2x, c2y) {
    UniversalCanvasContext.bezierCurveTo(this.contextId, x, y, c1x, c1y, c2x, c2y)
  }
  arc(x, y, r, sAngle, eAngle, counterclockwise) {
    UniversalCanvasContext.arc(this.contextId, x, y, r, sAngle, eAngle, counterclockwise)
  }
  arcTo(x1, y1, x2, y2, r) {
    UniversalCanvasContext.arcTo(this.contextId, x1, y1, x2, y2, r)
  }
  ellipse(x, y, radiusX, radiusY, r, sAngle, eAngle, counterclockwise) {
    UniversalCanvasContext.ellipse(this.contextId, x, y, r, sAngle, eAngle, counterclockwise)
  }
  //isPointInPath(x,y) {
  //  UniversalCanvasContext.isPointInPath(this.contextId,x,y)
  //}

  // Transformations
  scale(scalewidth, scaleheight) {
    UniversalCanvasContext.scale(this.contextId, scalewidth, scaleheight)
  }
  rotate(angle) {
    UniversalCanvasContext.rotate(this.contextId, angle)
  }
  translate(x, y) {
    UniversalCanvasContext.translate(this.contextId, x, y)
  }
  transform(a, b, c, d, e, f) {
    UniversalCanvasContext.transform(this.contextId, a, b, c, d, e, f)
  }
  setTransform(a, b, c, d, e, f) {
    UniversalCanvasContext.setTransform(this.contextId, a, b, c, d, e, f)
  }

  // Text
  set font(font) {
    UniversalCanvasContext.setFont(this.contextId, font)
  }
  set textAlign(textAlign) {
    UniversalCanvasContext.setTextAlign(this.contextId, textAlign)
  }
  set textBaseline(textBaseline) {
    UniversalCanvasContext.setTextBaseline(this.contextId, textBaseline)
  }
  set direction(direction) {
    UniversalCanvasContext.setDirection(this.contextId, direction)
  }
  fillText(text, x, y, maxWidth) {
    UniversalCanvasContext.fillText(this.contextId, '' + text, x, y, maxWidth)
  }
  strokeText() {
    UniversalCanvasContext.strokeText(this.contextId)
  }
  //measureText(text) {
  //  UniversalCanvasContext.measureText(this.contextId,text)
  //}

  // // Image Drawing
  // drawImage() {
  // }

  // set Data() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
  // createImageData() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
  // getImageData() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
  // putImageData() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }

  // Compositing
  set globalAlpha(alpha) {
    UniversalCanvasContext.setGlobalAlpha(this.contextId, alpha)
  }
  set globalCompositeOperation(globalCompositeOperation) {
    UniversalCanvasContext.setGlobalCompositeOperation(this.contextId, globalCompositeOperation)
  }

  // Other
  save() {
    UniversalCanvasContext.save(this.contextId)
  }
  restore() {
    UniversalCanvasContext.restore(this.contextId)
  }
  // createEvent() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
  // getContext() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
  // toDataURL() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
}

module.exports = Context

==> react-universal-canvas-0.2.7.tgz: package/src/context.js <==
import { NativeModules } from 'react-native'
import color from './color'

const { UniversalCanvasContext } = NativeModules

class Context {
  constructor(contextId) {
    this.contextId = contextId
    this.props = {
      lineWidth: 1
    }
  }
  setContext(contextId) {
    this.contextId = contextId
  }
  update() {
    UniversalCanvasContext.update(this.contextId)
  }

  // Colors,Styles,and Shadows
  set fillStyle(fillStyle) {
    UniversalCanvasContext.setFillStyle(this.contextId, color(fillStyle))
  }
  set strokeStyle(strokeStyle) {
    UniversalCanvasContext.setStrokeStyle(this.contextId, color(strokeStyle))
  }
  set shadowColor(shadowColor) {
    UniversalCanvasContext.setShadowColor(this.contextId, color(shadowColor))
  }
  set shadowBlur(shadowBlur) {
    UniversalCanvasContext.setShadowBlur(this.contextId, shadowBlur)
  }
  set shadowOffsetX(shadowOffsetX) {
    UniversalCanvasContext.setShadowOffsetX(this.contextId, shadowOffsetX)
  }
  set shadowOffsetY(shadowOffsetY) {
    UniversalCanvasContext.setShadowOffsetY(this.contextId, shadowOffsetY)
  }
  createLinearGradient() {
    UniversalCanvasContext.createLinearGradient(this.contextId)
  }
  createPattern() {
    UniversalCanvasContext.createPattern(this.contextId)
  }
  createRadialGradient() {
    UniversalCanvasContext.createRadialGradient(this.contextId)
  }
  addColorStop() {
    UniversalCanvasContext.addColorStop(this.contextId)
  }

  // Line Styles
  set lineCap(lineCap) {
    UniversalCanvasContext.setLineCap(this.contextId, lineCap)
  }
  set lineJoin(lineJoin) {
    UniversalCanvasContext.setLineJoin(this.contextId, lineJoin)
  }
  set lineWidth(lineWidth) {
    UniversalCanvasContext.setLineWidth(this.contextId, lineWidth)
  }
  set miterLimit(miterLimit) {
    UniversalCanvasContext.setMiterLimit(this.contextId, miterLimit)
  }
  //getLineDash() {
  //  UniversalCanvasContext.setMiterLimit(this.contextId,miterLimit)
  //}
  setLineDash(lineDash) {
    UniversalCanvasContext.setLineDash(this.contextId, lineDash)
  }
  set lineDashOffset(lineDashOffset) {
    UniversalCanvasContext.setLineDashOffset(this.contextId, lineDashOffset)
  }

  // Rectangle
  rect(x, y, width, height) {
    UniversalCanvasContext.rect(this.contextId, x, y, width, height)
  }
  fillRect(x, y, width, height) {
    UniversalCanvasContext.fillRect(this.contextId, x, y, width, height)
  }
  strokeRect(x, y, width, height) {
    UniversalCanvasContext.strokeRect(this.contextId, x, y, width, height)
  }
  clearRect(x, y, width, height) {
    UniversalCanvasContext.clearRect(this.contextId, x, y, width, height)
  }

  // Paths
  fill() {
    UniversalCanvasContext.fill(this.contextId)
  }
  stroke() {
    UniversalCanvasContext.stroke(this.contextId)
  }
  beginPath() {
    UniversalCanvasContext.beginPath(this.contextId)
  }
  moveTo(x, y) {
    UniversalCanvasContext.moveTo(this.contextId, x, y)
  }
  closePath() {
    UniversalCanvasContext.closePath(this.contextId)
  }
  lineTo(x, y) {
    UniversalCanvasContext.lineTo(this.contextId, x, y)
  }
  clip() {
    UniversalCanvasContext.clip(this.contextId)
  }
  quadraticCurveTo(x, y, cx, cy) {
    UniversalCanvasContext.quadraticCurveTo(this.contextId, x, y, cx, cy)
  }
  bezierCurveTo(x, y, c1x, c1y, c2x, c2y) {
    UniversalCanvasContext.bezierCurveTo(this.contextId, x, y, c1x, c1y, c2x, c2y)
  }
  arc(x, y, r, sAngle, eAngle, counterclockwise) {
    UniversalCanvasContext.arc(this.contextId, x, y, r, sAngle, eAngle, counterclockwise||false)
  }
  arcTo(x1, y1, x2, y2, r) {
    UniversalCanvasContext.arcTo(this.contextId, x1, y1, x2, y2, r)
  }
  ellipse(x, y, radiusX, radiusY, r, sAngle, eAngle, counterclockwise) {
    UniversalCanvasContext.ellipse(this.contextId, x, y, r, sAngle, eAngle, counterclockwise||false)
  }
  //isPointInPath(x,y) {
  //  UniversalCanvasContext.isPointInPath(this.contextId,x,y)
  //}

  // Transformations
  scale(scalewidth, scaleheight) {
    UniversalCanvasContext.scale(this.contextId, scalewidth||1, scaleheight||1)
  }
  rotate(angle) {
    UniversalCanvasContext.rotate(this.contextId, angle)
  }
  translate(x, y) {
    UniversalCanvasContext.translate(this.contextId, x, y)
  }
  transform(a, b, c, d, e, f) {
    UniversalCanvasContext.transform(this.contextId, a, b, c, d, e, f)
  }
  setTransform(a, b, c, d, e, f) {
    UniversalCanvasContext.setTransform(this.contextId, a, b, c, d, e, f)
  }

  // Text
  set font(font) {
    UniversalCanvasContext.setFont(this.contextId, font)
  }
  set textAlign(textAlign) {
    UniversalCanvasContext.setTextAlign(this.contextId, textAlign)
  }
  set textBaseline(textBaseline) {
    UniversalCanvasContext.setTextBaseline(this.contextId, textBaseline)
  }
  set direction(direction) {
    UniversalCanvasContext.setDirection(this.contextId, direction)
  }
  fillText(text, x, y, maxWidth) {
    UniversalCanvasContext.fillText(this.contextId, '' + text, x, y, maxWidth)
  }
  strokeText() {
    UniversalCanvasContext.strokeText(this.contextId)
  }
  async measureText(text) {
    return await UniversalCanvasContext.measureText(this.contextId,text);
  }

  // // Image Drawing
  // drawImage() {
  // }

  // set Data() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
  // createImageData() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
  // getImageData() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
  // putImageData() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }

  // Compositing
  set globalAlpha(alpha) {
    UniversalCanvasContext.setGlobalAlpha(this.contextId, alpha)
  }
  set globalCompositeOperation(globalCompositeOperation) {
    UniversalCanvasContext.setGlobalCompositeOperation(this.contextId, globalCompositeOperation)
  }

  // Other
  save() {
    UniversalCanvasContext.save(this.contextId)
  }
  restore() {
    UniversalCanvasContext.restore(this.contextId)
  }
  // createEvent() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
  // getContext() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
  // toDataURL() {
  //  UniversalCanvasContext.setLineWidth(this.contextId,lineWidth)
  // }
}

module.exports = Context
